@@ -7,7 +7,7 @@ def download_data(key):
     Examples
     --------
     >>> from ploomber.cloud import download_data
-    >>> download_data('raw.csv')
+    >>> download_data('raw.csv') # doctest: +SKIP
     """
     # TODO: this should find the root directory and download relative to it
     # then return the absolute path
