@@ -487,6 +487,44 @@ class NotebookRunner(NotebookMixin, Task):
 
     Examples
     --------
+
+    Spec API:
+
+    .. code-block:: yaml
+        :class: text-editor
+        :name: pipeline-yaml
+
+        tasks:
+          - source: nb.ipynb
+            product: report.html
+
+    Spec API (multiple outputs):
+
+    .. code-block:: yaml
+        :class: text-editor
+        :name: pipeline-yaml
+
+        tasks:
+          - source: nb.ipynb
+            product:
+                # generated automatically by ploomber
+                nb: report.html
+                # must be generated by nb.ipynb
+                data: data.csv
+
+    Python API:
+
+    >>> from pathlib import Path
+    >>> from ploomber import DAG
+    >>> from ploomber.tasks import NotebookRunner
+    >>> from ploomber.products import File
+    >>> dag = DAG()
+    >>> NotebookRunner(Path('nb.ipynb'), File('report.html'), dag=dag)
+    NotebookRunner: nb -> File('report.html')
+    >>> dag.build() # doctest: +SKIP
+
+    Python API (customize output notebook):
+
     >>> from pathlib import Path
     >>> from ploomber import DAG
     >>> from ploomber.tasks import NotebookRunner
@@ -495,15 +533,17 @@ class NotebookRunner(NotebookMixin, Task):
     >>> # do not include input code (only cell's output)
     >>> NotebookRunner(Path('nb.ipynb'), File('out-1.html'), dag=dag,
     ...                nbconvert_export_kwargs={'exclude_input': True},
-    ...                name=1) # doctest: +SKIP
+    ...                name='one')
+    NotebookRunner: one -> File('out-1.html')
     >>> # Selectively remove cells with the tag "remove"
     >>> config = {'TagRemovePreprocessor': {'remove_cell_tags': ('remove',)},
     ...        'HTMLExporter':
     ...         {'preprocessors':
-    ...    ['nbconvert.preprocessors.TagRemovePreprocessor']}} # doctest: +SKIP
+    ...    ['nbconvert.preprocessors.TagRemovePreprocessor']}}
     >>> NotebookRunner(Path('nb.ipynb'), File('out-2.html'), dag=dag,
     ...                nbconvert_export_kwargs={'config': config},
-    ...                name=2) # doctest: +SKIP
+    ...                name='another')
+    NotebookRunner: another -> File('out-2.html')
     >>> dag.build() # doctest: +SKIP
 
     Notes
@@ -638,7 +678,34 @@ class ScriptRunner(NotebookMixin, Task):
     Similar to NotebookRunner, except it uses python to run the code,
     instead of papermill, hence, it doesn't generate an output notebook. But
     it also works by injecting a cell into the source code. Source can be
-    a .py script or an .ipynb notebook. Does not support magics.
+    a ``.py`` script or an ``.ipynb`` notebook. **Does not support magics.**
+
+    Examples
+    --------
+
+    Spec API:
+
+    .. code-block:: yaml
+        :class: text-editor
+        :name: pipeline-yaml
+
+        tasks:
+          - source: script.py
+            class: ScriptRunner
+            product:
+                data: data.csv
+                another: another.csv
+
+    Python API:
+
+    >>> from pathlib import Path
+    >>> from ploomber import DAG
+    >>> from ploomber.tasks import ScriptRunner
+    >>> from ploomber.products import File
+    >>> dag = DAG()
+    >>> product = {'data': File('data.csv'), 'another': File('another.csv')}
+    >>> _ = ScriptRunner(Path('script.py'), product, dag=dag)
+    >>> _ = dag.build()
     """
     @requires(['jupyter', 'jupytext'], 'ScriptRunner')
     def __init__(self,
